## 4.3.0.20260402 (2026-04-02)

Rename `requires` to `dependencies` in METADATA files ([#15594](https://github.com/python/typeshed/pull/15594))

[channels] Use `async def` instead of a decorator ([#15590](https://github.com/python/typeshed/pull/15590))

## 4.3.0.20260321 (2026-03-21)

[channels] Relax django-stubs dependency ([#15524](https://github.com/python/typeshed/pull/15524))

## 4.3.0.20250822 (2025-08-22)

Add missing defaults to third-party stubs ([#14617](https://github.com/python/typeshed/pull/14617))

## 4.3.0.20250730 (2025-07-30)

[channels] Bump to `4.3.*` ([#14490](https://github.com/python/typeshed/pull/14490))

## 4.2.0.20250712 (2025-07-12)

Django channels stubs ([#13939](https://github.com/python/typeshed/pull/13939))

